# Django Silly Auth

## Why one more authentication system for Django and DRF? again !

I've used a few ones, and did not find the one that behaves the way I want,
efficient, but flexible, I wanted to gain som time, and get what I need straight to the point.

The aim of DSA it to provide a good-enough-to-go authentication out of the box, but still remains highly
modular through its SILLY_AUTH config in **settings.py**, so it is always possible to improve your
authentication when you have the time for it.

## DRF and Django Classic supported
DSA works as well with both DRF and Classic, just use differents simple settings, and you're done.


<hr>

# [WIKI documentation](https://github.com/byoso/django_silly_auth/wiki)

## [Read this FIRST](https://github.com/byoso/django_silly_auth/wiki/Must-read-this-few-lines-!)

### :coffee: [If you find this package usefull, consider buying me a coffee](https://www.buymeacoffee.com/byoso)


### Changelog

- 1.0.8: normalized messages, both errors and success
- 1.0.7: login improved: returns 'auth_token', errors are json objects.
- 1.0.5: test coverage: 75 %
- 1.0.1: **i18n** fr + en
